#!/bin/bash

#PBS -N raman
#PBS -r n
#PBS -e raman.err
#PBS -o raman.log
#PBS -q parallel
#PBS -l nodes=2:ppn=2

#@ job_type = parallel
#@ notification = never
#@ wall_clock_limit =01:00:00
#@ total_tasks = 4
#@ queue

OUTDIR=$HOME/BUGS/
PSEDIR=$HOME/BUGS/
TMPDIR=/scr/giannozz/tmp/
NPROCS=`wc -l < $PBS_NODEFILE`
BINDIR="mpirun -v -machinefile $PBS_NODEFILE -np $NPROCS $HOME/espresso/bin/"
# BINDIR="mpirun -v -machinefile $HOME/nodefile -np 4 $HOME/espresso/bin/"

#OUTDIR=$HOME/data/BUGS/
#PSEDIR=$HOME/data/BUGS/
#TMPDIR=/scratch/PG/
#BINDIR="poe $HOME/data/espresso/bin/"

cd $TMPDIR

$BINDIR/pw.x > $OUTDIR/SnO.out << EOF
 &control
    calculation = 'scf'
    restart_mode='from_scratch',
    prefix='SnO',
    pseudo_dir = '$PSEDIR/',
    outdir='$TMPDIR/'
 /
 &system
    ibrav=6, celldm(1)=7.2662, celldm(3) =1.2784, 
    nat=4, ntyp=2, ecutwfc =70
 /
 &electrons
    mixing_beta = 0.7
    conv_thr =  1.0d-8
 /
ATOMIC_SPECIES
 Sn  118.69  Sn.cpi.UPF
 O   15.999  O.cpi.UPF
ATOMIC_POSITIONS {crystal}
 Sn 0.5 0.0 0.2345447
 Sn 0.0 0.5 0.7654553
 O  0.0 0.0 0.000
 O  0.5 0.5 0.000
K_POINTS {automatic}
2 2 1 0 0 0
EOF

$BINDIR/ph.x > $OUTDIR/SnOph.out << EOF
 phonons of SnO at Gamma
 &inputph
 tr2_ph=1.0d-15,
  prefix='SnO',
  epsil=.true.,
  amass(1)=118.69,
  amass(2)=15.999,
  trans=.true.,
  lraman=.true.,
  elop=.true.
  outdir='$TMPDIR/'
  fildyn='SnO.dynG',
 fildrho='SnO.drho',
 /
0.0 0.0 0.0
EOF
